% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{pkg_sys}
\alias{pkg_sys}
\title{Wrapper for \code{system.file} for this package}
\usage{
pkg_sys(..., package = utils::packageName(), lib.loc = NULL, mustWork = FALSE)
}
\arguments{
\item{...}{character vectors, specifying subdirectory and file(s)
    within some package.  The default, none, returns the
    root of the package.  Wildcards are not supported.}

\item{package}{a character string with the name of a single package.
    An error occurs if more than one package name is given.}

\item{lib.loc}{a character vector with path names of \R libraries.
    See \sQuote{Details} for the meaning of the default value of \code{NULL}.}

\item{mustWork}{logical.  If \code{TRUE}, an error is given if there
    are no matching files.}
}
\value{
A character vector of positive length, containing the file paths
  that matched \code{\dots}, or the empty string, \code{""}, if none
  matched (unless \code{mustWork = TRUE}).

  If matching the root of a package, there is no trailing separator.

  \code{system.file()} with no arguments gives the root of the
  \pkg{base} package.
}
\description{
Finds the full file names of files in packages etc.
}
\details{
This checks the existence of the specified files with
  \code{\link[base]{file.exists}}.  So file paths are only returned if there
  are sufficient permissions to establish their existence.

  The unnamed arguments in \code{...} are usually character strings, but
  if character vectors they are recycled to the same length.

  This uses \code{\link[base]{find.package}} to find the package, and hence
  with the default \code{lib.loc = NULL} looks first for attached
  packages then in each library listed in \code{\link[base]{.libPaths}()}.
  Note that if a namespace is loaded but the package is not attached,
  this will look only on \code{\link[base]{.libPaths}()}.
}
\examples{
pkg_sys()

}
\seealso{
\code{\link[base]{R.home}} for the root directory of the \R
  installation, \code{\link[base]{list.files}}.

  \code{\link[base]{Sys.glob}} to find paths via wildcards.
}
